starcluster.managers.Manager

Package starcluster :: Module managers :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

Base class for all Manager classes in StarCluster

Instance Methods | [hide private]
__init__(self, cfg, ec2=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, cfg, ec2=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)